@@ -118,6 +118,11 @@ class KinovaGen3Arm(robot_arms.RobotArm):
         joints = self.feedback.actuators
         return [joint.position for joint in joints]
 
+    @property
+    def joint_torques(self) -> List[float]:
+        joints = self.feedback.actuators
+        return [joint.torque for joint in joints]
+
     @property
     def joint_count(self):
         if self._joint_count is not None:
