@@ -1,7 +1,7 @@
 from typing import Dict, List, Optional, Tuple
 import json
 from hein_robots.kinova.kinova_gen3 import KinovaGen3Arm
-from hein_robots.kinova.kortex import Base_pb2, BaseClient
+from hein_robots.kinova.kortex import Base_pb2, BaseClient, KortexConnection
 from hein_robots.robotics import Location
 from hein_robots.grids import LocationGroup
 
@@ -68,8 +68,8 @@ class KortexSequence(LocationGroup):
         self.arm = arm
         self.name = name
         self.sequence_handle = self.find_sequence_handle(self.arm.connection.client, name)
-        self.locations = KortexSequenceLocations(self.arm.connection.client, self.sequence_handle, self.name)
-        self.joints = KortexSequenceJoints(self.arm.connection.client, self.sequence_handle, self.name)
+        self.locations = KortexSequenceLocations(self.arm.connection, self.sequence_handle, self.name)
+        self.joints = KortexSequenceJoints(self.arm.connection, self.sequence_handle, self.name)
 
     def __len__(self):
         return len(self.locations)
@@ -89,14 +89,14 @@ class KortexSequenceLocations:
 
         return location.convert_m_to_mm()
 
-    def __init__(self, client: BaseClient, sequence_handle,  task_name: str):
-        self.client = client
+    def __init__(self, connection: KortexConnection, sequence_handle,  task_name: str):
+        self.connection = connection
         self.sequence_handle = sequence_handle
         self.task_name = task_name
 
     @property
     def sequence(self):
-        return self.client.ReadSequence(self.sequence_handle)
+        return self.connection.client.ReadSequence(self.sequence_handle)
 
     @property
     def location_tasks(self):
@@ -127,14 +127,14 @@ class KortexSequenceJoints:
 
         return [joint.value for joint in joints]
 
-    def __init__(self, client: BaseClient, sequence_handle, task_name: str):
-        self.client = client
+    def __init__(self, connection: KortexConnection, sequence_handle, task_name: str):
+        self.connection = connection
         self.sequence_handle = sequence_handle
         self.task_name = task_name
 
     @property
     def sequence(self):
-        return self.client.ReadSequence(self.sequence_handle)
+        return self.connection.client.ReadSequence(self.sequence_handle)
 
     @property
     def joint_tasks(self):
